@@ -23,7 +23,6 @@ def dash_upsert_data(deploy_data):
         "layout": deploy_data["layout"],
         "draft_layout": None,
         "theme": deploy_data.get("theme", None),
-        "show_sidebar": deploy_data.get("show_sidebar", False),
         "font_family": deploy_data.get("font_family", None),
         "main_color": deploy_data.get("main_color", None),
         "logo_url": deploy_data.get("logo_url", None),
@@ -135,3 +134,51 @@ def delete_workspace_dash(path):
     """
 
     return api_main.hf_hasura_runner(query, {"path": path})
+
+
+def list_logs(limit, offset):
+    query = """
+        query GetDashLogs {
+            dashes {
+                id
+                path
+                logs {
+                    id
+                    created_at
+                    execution_id
+                    search_term
+                    execution_type
+                    messages
+                }
+            }
+        }
+    """
+    dashes = api_main.hf_hasura_runner(query).get("dashes")
+    logs = utils.flat_items_logs(dashes, path_or_id="path")
+
+    return {"logs": utils.sampling(logs, limit, offset)}
+
+
+def list_logs_by_path(path, limit, offset):
+    query = """
+        query GetDashLogs($limit: Int, $offset: Int, $path: String = "") {
+            dashes(where: {path: {_eq: $path}}) {
+                path
+                logs(offset: $offset, limit: $limit, order_by: {created_at: desc}) {
+                    id
+                    created_at
+                    dash_id
+                    execution_id
+                    search_term
+                    execution_type
+                    messages
+                }
+            }
+        }
+    """
+    dashes = api_main.hf_hasura_runner(
+        query, {"path": path, "limit": limit, "offset": offset}
+    ).get("dashes")
+    if dashes:
+        return {"logs": utils.flatten_list([dash.get("logs") for dash in dashes])}
+    return {"logs": []}
