@@ -13,6 +13,7 @@ from abstra_cli.resources import (
     Jobs,
     Dashes,
     Subdomains,
+    Workspaces,
 )
 
 
@@ -118,6 +119,18 @@ class CLI(object):
 
         play_func(*args, **kwargs)
 
+    def logs(self, resource, *args, **kwargs):
+        checkers.credentials_check("logs", resource, *args, **kwargs)
+        logs_func = {
+            "dash": Dashes.logs,
+            "form": Forms.logs,
+            "hook": Hooks.logs,
+            "job": Jobs.logs,
+            "workspace": Workspaces.logs,
+        }.get(resource, messages.not_implemented)
+
+        logs_func(*args, **kwargs)
+
     # Aliases
     def upload(self, *args, **kwargs):
         if not len(args):
