@@ -1,3 +1,4 @@
+import sys
 from abstra_cli.resources.resources import Resource
 import abstra_cli.messages as messages
 import abstra_cli.utils as utils
@@ -18,21 +19,25 @@ class Vars(Resource):
             with open(file, "r") as f:
                 vars.extend([v for v in f.read().split("\n") if v])
 
+        if len(vars) == 0:
+            messages.no_variables()
+            return
+
         processed_vars = []
         processed_names = []
         for var in vars:
             name, value = utils.parse_env_var(var)
             if not name or not value:
                 messages.invalid_variable(var)
-                return False
+                sys.exit(1)
             if name in processed_names:
                 messages.duplicate_variable(var)
-                return False
+                sys.exit(1)
             processed_vars.append({"name": name, "value": value})
 
         added_vars = apis.add_workspace_vars(processed_vars)
         messages.print_vars(added_vars)
-        print(f"\nAdded {len(added_vars)} enviroment variables")
+        print(f"\nAdded {len(added_vars)} environment variables")
 
     @staticmethod
     def remove(*args, **kwargs):
